@@ -1,8 +1,9 @@
-from random_variable import RandomVariable
+from cvxstoc.random_variable import RandomVariable
 from cvxpy.transforms.partial_optimize import PartialProblem
 from cvxpy import Problem
 import copy
 
+
 def replace_rand_vars(obj):
     """Replaces all random variables with copies.
 
@@ -26,16 +27,12 @@ def replace_rand_vars(obj):
         new_obj = replace_rand_vars(prob.objective)
         new_constr = []
         for constr in prob.constraints:
-            new_constr.append(
-                replace_rand_vars(constr)
-            )
+            new_constr.append(replace_rand_vars(constr))
         new_args = [Problem(new_obj, new_constr)]
         return obj.copy(new_args)
     # Parent nodes are copied.
     else:
         new_args = []
         for arg in obj.args:
-            new_args.append(
-                replace_rand_vars(arg)
-            )
+            new_args.append(replace_rand_vars(arg))
         return obj.copy(new_args)
